<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'Bescherming van forums tegen cross-site scripting',
	'safehtml_slogan' => 'Bescherming van forums tegen cross-site scripting',
];
